;IO State Machine
; Inspired by Woz' Disk II Controller. Seriously.
; The idea: use a ROM to define the entire memory map. I can then define any chip selection I want all the way down to individual memory locations.

/*
Select Map
Select Line		ROM Data Bit	Select Type
--------------------------------------------
[unused]		7				--
KB_SEL			6				0
SND_SEL			5				1
[unused]		4				--
ACIA0_SEL		3				1
IOSEL			2				0
ROMSEL			1				0
RAMSEL			0				0


Memory Bit Map							
						76543210
RAMSEL		0000-CFFF	|10|0110
ACIA0		D000-D003	|10|1011
[unused]	D004-D00F	|10|0011	(i.e. only IOSEL)
[unused]	D010-D01F	|10|0011	(i.e. only IOSEL)	
Sound VIA	D020-D02F	|11|0011	
KBSEL		D030-D031	|00|0011
[unused]    D032-DFFF	|10|0011	(i.e. only IOSEL)
ROMSEL		E000-FFFF	|10|0101
						76543210
						
Note: 	Mapper outputs could be made more efficient by using an inverter on the device select lines and eliminating IOSEL 
		IO Space can be made more efficient by simply nudging the memory spaces together. It was redesigned in this manner
		to make the new mapping system compatible with all my existing code.
		
		I may change these things at a later point, but as it stands, I have PLENTY of IO space.				
*/

.target "65C02"	; We're running a 65C02 Processor

; RAMSEL
	* = $0000
	.Loop 53248
	.byte $46	;01000110
	.endloop

; Device Selection
	* = $D000
	.Loop 4096	;Flood IO with only IOSEL, in case we forget to select for something
	.byte $43	;01000011
	.endloop
	
	
	;ACIA0
	* = $D000
	.Loop 4
	.byte $4B	;01001011
	.endloop
	
	;Sound VIA
	* = $D020
	.Loop 16
	.byte $63	;01100011
	.endloop
	
	;Keyboard
	* = $D030
	.byte $03	;00000011
	.byte $03
	

; ROMSEL
	* = $E000
	.Loop 8192
	.byte $45	;01000101
	.endloop
